<?php
/**
 * Set outspoken layout according to options
 *
 * @package Outspoken
 */

defined( 'WPINC' ) || exit;

/**
 * Layout manager.
 */
class Outspoken_Layout extends Outspoken_Base {

	/**
	 * The Construct
	 */
	public function __construct() {
		$this->add_action( 'outspoken_before_wrapper', 'add_header' );
		$this->add_action( 'outspoken_single_post_header_thumb', 'single_post_header_thumb' );
		$this->add_action( 'outspoken_before_footer', 'full_related_posts' );
	}

	/**
	 * Add header
	 */
	public function add_header() {
		$hash   = array(
			'header-default' => 'default',
			'header-layout2' => 'layout2',
		);
		$layout = outspoken_get_settings( 'header_styles' );
		get_template_part( 'template-parts/header/header', isset( $hash[ $layout ] ) ? $hash[ $layout ] : $layout );
	}

	/**
	 * Single post header thumbnail
	 */
	public function single_post_header_thumb() {

		$header_animation = outspoken_get_post_header_effect();

		if ( ! $header_animation && outspoken_get_settings( 'show_single_featured' ) ) {
			$attr = [
				'class'   => 'single-featured-image',
				'title'   => esc_attr( get_the_title() ),
				'alt'     => esc_attr( get_the_title() ),
				'loading' => 'lazy',
			];
			echo '<div class="single-featured-wrap">';
			the_post_thumbnail( 'outspoken-single-featured', $attr );
			echo '</div>';
		}

	}

	/**
	 * Single post related posts
	 */
	public function full_related_posts( $position = 'full' ) {

		if ( 'full' === outspoken_get_settings( 'related_posts_position' ) ) {
			outspoken_related_posts();
		}

	}

}

// Init.
new Outspoken_Layout;
