<?php
/**
 * HomePage Posts
 *
 * @package Outspoken
 */

$features = outspoken_get_settings( 'featured_categories' );
if ( empty( $features ) ) {
	return;
}
foreach ( $features as $feature ) :
	$title        = isset( $feature['mts_featured_title'] ) ? $feature['mts_featured_title'] : 'No Title';
	$posts_layout = isset( $feature['blog_layout'] ) ? $feature['blog_layout'] : '';
	if ( 'layout-default' === $posts_layout ) {
		$posts_layout = 'default';
	}
	$unique_id = isset( $feature['unique_id'] ) ? $feature['unique_id'] : '';

	$menus['blog']['child'][ 'blog-' . $unique_id ] = array(
		'title' => $title,
		// translators: description.
		'desc'  => sprintf( wp_kses_post( __( 'From here, you can control the elements of %s', 'outspoken' ) ), $title ),
	);

	// Dependency check that back to top option is enable.
	$post_title_dependency = array(
		'relation' => 'and',
		array(
			'field'      => 'featured_category_title_' . $unique_id,
			'value'      => '1',
			'comparison' => '==',
		),
	);

	$sections[ 'blog-' . $unique_id ] = array(

		/**
		 * Layout Default Settings
		 *
		 * @package Outspoken
		 */

		// Section Title.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'outspoken' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'outspoken' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'outspoken' ),
			'std'      => '0',
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'outspoken' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'outspoken' ),
				'center' => esc_html__( 'Center', 'outspoken' ),
				'right'  => esc_html__( 'Right', 'outspoken' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'outspoken' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'outspoken' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '30px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'outspoken' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Select border', 'outspoken' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'outspoken' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '16px',
				'color'          => '#2b2b2b',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'outspoken' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_categories_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Post Categories', 'outspoken' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Post Categories.', 'outspoken' ),
			'std'      => '1',
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'outspoken' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'outspoken' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'outspoken' ),
			'sub_desc' => esc_html__( 'Select border.', 'outspoken' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Categories Typography', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Categories Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'margin-top'     => '-8px',
				'color'          => '#ec5050',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.456px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .thecategory',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '500',
				'font-size'      => '12px',
				'margin-top'     => '12px',
				'color'          => '#595959',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.456px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'outspoken' ),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'outspoken' ),
			'sub_desc' => esc_html__( 'Select border', 'outspoken' ),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post margin.', 'outspoken' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '56px',
				'bottom' => '0',
			),
		) : null,
		( 'default' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post padding.', 'outspoken' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '32px',
				'line-height'    => '36px',
				'color'          => '#2b2b2b',
				'additional-css' => 'letter-spacing: -0.512px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'default' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'outspoken' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Red Hat Text',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'margin-top'    => '4px',
				'line-height'   => '22px',
				'color'         => '#595959',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 1 with 2 sidebars Settings
		 *
		 * @package Outspoken
		 */
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_left_sidebar_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Left Sidebar', 'outspoken' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide left sidebar.', 'outspoken' ),
			'std'      => '1',
		) : null,

		// Meta info.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'outspoken' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_categories_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Post Categories', 'outspoken' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Post Categories.', 'outspoken' ),
			'std'      => '1',
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'outspoken' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'outspoken' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'outspoken' ),
			'sub_desc' => esc_html__( 'Select border.', 'outspoken' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Categories Typography', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Categories Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'margin-top'     => '-3px',
				'color'          => '#ec5050',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.456px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .thecategory',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '500',
				'font-size'      => '12px',
				'margin-top'     => '4px',
				'color'          => '#595959',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.456px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'outspoken' ),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'outspoken' ),
			'sub_desc' => esc_html__( 'Select border', 'outspoken' ),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post margin.', 'outspoken' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '68px',
				'bottom' => '0',
			),
		) : null,
		( 'layout-1' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post padding.', 'outspoken' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '32px',
				'line-height'    => '36px',
				'color'          => '#2b2b2b',
				'additional-css' => 'text-transform: uppercase; letter-spacing: -0.256px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_small_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Small Title Font', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Small Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '18px',
				'line-height'    => '22px',
				'color'          => '#2b2b2b',
				'additional-css' => 'text-transform: none;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.small .title a',
			),
		) : null,

		( 'layout-1' === $posts_layout ) ? array(
			'id'    => 'post_excerpt_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Excerpt Font', 'outspoken' ),
			'std'   => array(
				'preview-text'  => 'Post Excerpt Font',
				'preview-color' => 'light',
				'font-family'   => 'Red Hat Text',
				'font-weight'   => '400',
				'font-size'     => '16px',
				'margin-top'    => '3px',
				'line-height'   => '22px',
				'color'         => '#595959',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .front-view-content',
			),
		) : null,

		/**
		 * Layout 2 Settings
		 *
		 * @package Outspoken
		 */

		// Section Title.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'outspoken' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'outspoken' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'outspoken' ),
			'std'      => '0',
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'outspoken' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'outspoken' ),
				'center' => esc_html__( 'Center', 'outspoken' ),
				'right'  => esc_html__( 'Right', 'outspoken' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'outspoken' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'outspoken' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '20px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'outspoken' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Select border', 'outspoken' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'outspoken' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '16px',
				'color'          => '#2b2b2b',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'outspoken' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_categories_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Post Categories', 'outspoken' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Post Categories.', 'outspoken' ),
			'std'      => '1',
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'outspoken' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'outspoken' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'outspoken' ),
			'sub_desc' => esc_html__( 'Select border.', 'outspoken' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Categories Typography', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Categories Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'margin-top'     => '-1px',
				'color'          => '#ec5050',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.456px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .thecategory',
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '500',
				'font-size'      => '12px',
				'margin-top'     => '4px',
				'color'          => '#595959',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.456px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'outspoken' ),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'outspoken' ),
			'sub_desc' => esc_html__( 'Select border', 'outspoken' ),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post margin.', 'outspoken' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '83px',
				'bottom' => '0',
			),
		) : null,
		( 'layout-2' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post padding.', 'outspoken' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '32px',
				'line-height'    => '36px',
				'color'          => '#2b2b2b',
				'additional-css' => 'letter-spacing: -0.512px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost.large .title a',
			),
		) : null,

		( 'layout-2' === $posts_layout ) ? array(
			'id'    => 'post_small_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Small Title Font', 'outspoken' ),
			'std'   => array(
				'preview-text'  => 'Post Small Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Red Hat Text',
				'font-weight'   => '700',
				'font-size'     => '18px',
				'line-height'   => '22px',
				'color'         => '#2b2b2b',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost.small .title a',
			),
		) : null,

		/**
		 * Layout grid Settings
		 *
		 * @package Outspoken
		 */

		// Section Title.
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_title_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Section Title', 'outspoken' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'featured_category_title_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Title', 'outspoken' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide title of post container.', 'outspoken' ),
			'std'      => '0',
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'post_title_alignment_' . $unique_id,
			'type'       => 'button_set',
			'title'      => esc_html__( 'Section Title Alignment', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Choose the section title alignment', 'outspoken' ),
			'options'    => array(
				'left'   => esc_html__( 'Left', 'outspoken' ),
				'center' => esc_html__( 'Center', 'outspoken' ),
				'right'  => esc_html__( 'Right', 'outspoken' ),
			),
			'std'        => 'left',
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_background_' . $unique_id,
			'type'       => 'background',
			'title'      => esc_html__( 'Post Title Background Color', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Set background color, pattern and image from here.', 'outspoken' ),
			'options'    => array(
				'color'         => '',            // false to disable, not needed otherwise.
				'image_pattern' => $mts_patterns, // false to disable, array of options otherwise ( required !!! ).
				'image_upload'  => '',            // false to disable, not needed otherwise.
				'repeat'        => array(),       // false to disable, array of options to override default ( optional ).
				'attachment'    => array(),       // false to disable, array of options to override default ( optional ).
				'position'      => array(),       // false to disable, array of options to override default ( optional ).
				'size'          => array(),       // false to disable, array of options to override default ( optional ).
				'gradient'      => '',            // false to disable, not needed otherwise.
				'parallax'      => array(),       // false to disable, array of options to override default ( optional ).
			),
			'std'        => array(
				'color'         => '',
				'use'           => 'pattern',
				'image_pattern' => 'nobg',
				'image_upload'  => '',
				'repeat'        => 'repeat',
				'attachment'    => 'scroll',
				'position'      => 'left top',
				'size'          => 'cover',
				'gradient'      => array(
					'from'      => '#ffffff',
					'to'        => '#000000',
					'direction' => '0deg',
				),
				'parallax'      => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_margin_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Margin', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Set section title margin from here.', 'outspoken' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '20px',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_padding_' . $unique_id,
			'type'       => 'margin',
			'title'      => esc_html__( 'Post Title Padding', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Set section title padding from here.', 'outspoken' ),
			'std'        => array(
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
				'left'   => '0',
			),
			'dependency' => $post_title_dependency,
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'post_title_border_' . $unique_id,
			'type'       => 'border',
			'title'      => esc_html__( 'Border', 'outspoken' ),
			'sub_desc'   => esc_html__( 'Select border', 'outspoken' ),
			'dependency' => $post_title_dependency,
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'         => 'featured_category_title_font_' . $unique_id,
			'type'       => 'typography',
			'title'      => esc_html__( 'Section Title Typography', 'outspoken' ),
			'std'        => array(
				'preview-text'   => 'Title Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '16px',
				'color'          => '#2b2b2b',
				'additional-css' => 'text-transform: uppercase;',
				'css-selectors'  => '.title-container.title-id-' . $unique_id . ' h3.featured-category-title',
			),
			'dependency' => $post_title_dependency,
		) : null,

		// Meta info.
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_meta_info_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Meta Info', 'outspoken' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_categories_' . $unique_id,
			'type'     => 'switch',
			'title'    => esc_html__( 'Show/Hide Post Categories', 'outspoken' ),
			'sub_desc' => esc_html__( 'Use this button to show or hide Post Categories.', 'outspoken' ),
			'std'      => '1',
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'mts_home_headline_meta_info' . $unique_id,
			'type'     => 'layout2',
			// translators: title.
			'title'    => sprintf( wp_kses_post( __( '%s Meta Info', 'outspoken' ) ), $title ),
			// translators: description.
			'sub_desc' => sprintf( wp_kses_post( __( 'Organize how you want the post meta info to appear on %s', 'outspoken' ) ), $title ),
			'options'  => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
			),
			'std'      => array(
				'enabled'  => array(
					'author' => array(
						'label'     => __( 'Author Name', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_author_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
				'disabled' => array(
					'date'    => array(
						'label'     => esc_html__( 'Date', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_date_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
					'comment' => array(
						'label'     => esc_html__( 'Comment Count', 'outspoken' ),
						'subfields' => array(
							array(
								'id'    => 'mts_meta_info_comment_icon_' . $unique_id,
								'type'  => 'icon_select',
								'title' => esc_html__( 'Select Icon', 'outspoken' ),
							),
						),
					),
				),
			),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'meta_info_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'outspoken' ),
			'sub_desc' => esc_html__( 'Select border.', 'outspoken' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_categories_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Categories Typography', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Categories Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '700',
				'font-size'      => '12px',
				'margin-top'     => '-3px',
				'color'          => '#ec5050',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.456px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .thecategory',
			),
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'meta_info_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Meta Info Typography', 'outspoken' ),
			'std'   => array(
				'preview-text'   => 'Post Meta Info Font',
				'preview-color'  => 'light',
				'font-family'    => 'Red Hat Text',
				'font-weight'    => '500',
				'font-size'      => '12px',
				'color'          => '#595959',
				'margin-top'     => '3px',
				'additional-css' => 'text-transform: uppercase; letter-spacing: 0.456px;',
				'css-selectors'  => '.layout-' . $unique_id . ' .latestPost .post-info, .layout-' . $unique_id . ' .latestPost .post-info a',
			),
		) : null,
		// Post Container.
		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_heading_' . $unique_id,
			'type'  => 'heading',
			'title' => esc_html__( 'Post Container', 'outspoken' ),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_border_' . $unique_id,
			'type'     => 'border',
			'title'    => esc_html__( 'Border', 'outspoken' ),
			'sub_desc' => esc_html__( 'Select border', 'outspoken' ),
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post margin.', 'outspoken' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '65px',
				'bottom' => '0',
			),
		) : null,
		( 'layout-grid' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post padding.', 'outspoken' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

		( 'layout-grid' === $posts_layout ) ? array(
			'id'    => 'post_title_font_' . $unique_id,
			'type'  => 'typography',
			'title' => esc_html__( 'Post Title Font', 'outspoken' ),
			'std'   => array(
				'preview-text'  => 'Post Title Font',
				'preview-color' => 'light',
				'font-family'   => 'Red Hat Text',
				'font-weight'   => '700',
				'font-size'     => '18px',
				'line-height'   => '22px',
				'color'         => '#2b2b2b',
				'css-selectors' => '.layout-' . $unique_id . ' .latestPost .title a',
			),
		) : null,

		/**
		 * Layout HTML Settings
		 *
		 * @package Outspoken
		 */
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_layout_html_' . $unique_id,
			'type'     => 'ace_editor',
			'mode'     => 'html',
			'title'    => esc_html__( 'HTML Post', 'outspoken' ),
			'sub_desc' => esc_html__( 'Paste your HTML, Text or other code here.', 'outspoken' ),
			'std'      => '<img src="' . get_template_directory_uri() . '/images/banner-970.jpg">',
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_margin_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Margin', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post margin.', 'outspoken' ),
			'left'     => false,
			'right'    => false,
			'std'      => array(
				'top'    => '45px',
				'bottom' => '0',
			),
		) : null,
		( 'layout-html' === $posts_layout ) ? array(
			'id'       => 'post_padding_' . $unique_id,
			'type'     => 'margin',
			'title'    => esc_html__( 'Padding', 'outspoken' ),
			'sub_desc' => esc_html__( 'Post padding.', 'outspoken' ),
			'std'      => array(
				'left'   => '0',
				'top'    => '0',
				'right'  => '0',
				'bottom' => '0',
			),
		) : null,

	);
endforeach;
