<?php
/**
 * Header Tab
 *
 * @package Outspoken
 */

$menus['header'] = array(
	'icon'  => 'fa-header',
	'title' => esc_html__( 'Header', 'outspoken' ),
);

$menus['header']['child']['header-general'] = array(
	'title' => esc_html__( 'General', 'outspoken' ),
	'desc'  => esc_html__( 'From here, you can control the elements of header section.', 'outspoken' ),
);

$default_header_only = array(
	'relation' => 'and',
	array(
		'field'      => 'header_styles',
		'value'      => 'header-layout2',
		'comparison' => '!=',
	),
);

$sections['header-general'] = array(

	array(
		'id'       => 'header_styles',
		'type'     => 'radio_img',
		'title'    => esc_html__( 'Header Styling', 'outspoken' ),
		'sub_desc' => wp_kses( __( 'Choose the <strong>Header design</strong> for your site.', 'outspoken' ), array( 'strong' => '' ) ),
		'options'  => array(
			'header-default' => array( 'img' => $uri . 'headers/header-default.jpg' ),
			'header-layout2' => array( 'img' => $uri . 'headers/header-layout2.jpg' ),
		),
		'std'      => 'header-default',
	),

	array(
		'id'       => 'header_date',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show/Hide Date', 'outspoken' ),
		'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Date</strong> in header.', 'outspoken' ), array( 'strong' => '' ) ),
		'std'      => '1',
	),
	array(
		'id'         => 'date_formats',
		'type'       => 'button_set',
		'title'      => esc_html__( 'Date Format', 'outspoken' ),
		'sub_desc'   => esc_html__( 'Select your date format.', 'outspoken' ),
		'options'    => array(
			'default'  => __( '<strong>Default Format</strong><br><small>From WordPress Settings</small>', 'outspoken' ),
			'D,-M-d-Y' => __( '<strong>D, M d Y</strong><br><small>Mon, Nov 16 2019</small>', 'outspoken' ),
			'custom'   => __( '<strong>Custom</strong><br><small>Select custom date</small>', 'outspoken' ),
		),
		'std'        => 'D,-M-d-Y',
		'dependency' => array(
			'relation' => 'and',
			array(
				'field'      => 'header_date',
				'value'      => '1',
				'comparison' => '==',
			),
		),
	),
	array(
		'id'         => 'custom_date',
		'type'       => 'text',
		'class'      => 'small-text',
		'title'      => esc_html__( 'Custom Date', 'outspoken' ),
		// translators: Anchor tag for date format characters.
		'sub_desc'   => sprintf( wp_kses_post( __( 'Use this field to set custom date format in header. You can see a full list of <a href="%s" target="_blank">format characters here</a>.', 'outspoken' ) ), 'https://www.php.net/manual/en/function.date.php' ),
		'std'        => 'D, M d Y',
		'dependency' => array(
			'relation' => 'and',
			array(
				'field'      => 'header_date',
				'value'      => '1',
				'comparison' => '==',
			),
			array(
				'field'      => 'date_formats',
				'value'      => 'custom',
				'comparison' => '==',
			),
		),
	),

	array(
		'id'         => 'header_social_icons',
		'title'      => esc_html__( 'Header Social Icons', 'outspoken' ),
		'sub_desc'   => esc_html__( 'Add Social Media icons in header.', 'outspoken' ),
		'type'       => 'group',
		'groupname'  => esc_html__( 'Header Icon', 'outspoken' ), // Group name.
		'subfields'  => array(
			array(
				'id'    => 'header_icon_title',
				'type'  => 'text',
				'title' => esc_html__( 'Title', 'outspoken' ),
			),
			array(
				'id'    => 'header_icon',
				'type'  => 'icon_select',
				'title' => esc_html__( 'Icon', 'outspoken' ),
			),
			array(
				'id'    => 'header_icon_link',
				'type'  => 'text',
				'title' => esc_html__( 'URL', 'outspoken' ),
			),
			array(
				'id'    => 'header_icon_bgcolor',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon background color', 'outspoken' ),
			),
			array(
				'id'    => 'header_icon_hover_bgcolor',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon background hover color', 'outspoken' ),
			),
			array(
				'id'    => 'header_icon_color',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon color', 'outspoken' ),
			),
			array(
				'id'    => 'header_icon_hover_color',
				'type'  => 'color',
				'title' => esc_html__( 'Header icon hover color', 'outspoken' ),
			),
			array(
				'id'    => 'header_icon_margin',
				'type'  => 'margin',
				'title' => esc_html__( 'Header icon Margin', 'outspoken' ),
			),
			array(
				'id'    => 'header_icon_padding',
				'type'  => 'margin',
				'title' => esc_html__( 'Header icon Padding', 'outspoken' ),
			),
			array(
				'id'    => 'header_icon_border_radius',
				'type'  => 'text',
				'class' => 'small-text',
				'title' => esc_html__( 'Header icon border radius', 'outspoken' ),
				'args'  => array( 'type' => 'number' ),
			),
		),
		'std'        => array(
			'facebook'  => array(
				'group_title'               => 'Facebook',
				'group_sort'                => '1',
				'header_icon_title'         => 'Facebook',
				'header_icon'               => 'facebook-official',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#a7a7a7',
				'header_icon_hover_color'   => outspoken_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),
			'youtube'   => array(
				'group_title'               => 'Youtube',
				'group_sort'                => '2',
				'header_icon_title'         => 'Youtube',
				'header_icon'               => 'youtube-play',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#a7a7a7',
				'header_icon_hover_color'   => outspoken_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),
			'twitter'   => array(
				'group_title'               => 'Twitter',
				'group_sort'                => '3',
				'header_icon_title'         => 'Twitter',
				'header_icon'               => 'twitter',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#a7a7a7',
				'header_icon_hover_color'   => outspoken_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),
			'pinterest' => array(
				'group_title'               => 'Pinterest',
				'group_sort'                => '4',
				'header_icon_title'         => 'Pinterest',
				'header_icon'               => 'pinterest',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#a7a7a7',
				'header_icon_hover_color'   => outspoken_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),
			'instagram' => array(
				'group_title'               => 'Instagram',
				'group_sort'                => '5',
				'header_icon_title'         => 'Instagram',
				'header_icon'               => 'instagram',
				'header_icon_link'          => '#',
				'header_icon_bgcolor'       => '',
				'header_icon_hover_bgcolor' => '',
				'header_icon_color'         => '#a7a7a7',
				'header_icon_hover_color'   => outspoken_get_settings( 'primary_color_scheme' ),
				'header_icon_margin'        => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '13px',
				),
				'header_icon_padding'       => array(
					'top'    => '0',
					'right'  => '0',
					'bottom' => '0',
					'left'   => '0',
				),
				'header_icon_border_radius' => '0',
			),

		),
		'dependency' => $default_header_only,
	),

	array(
		'id'    => 'header_general_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Header General Settings', 'outspoken' ),
	),

	array(
		'id'       => 'sticky_nav',
		'type'     => 'switch',
		'title'    => esc_html__( 'Floating Navigation Menu', 'outspoken' ),
		// translators: Floating Navigation Menu with strong tag.
		'sub_desc' => sprintf( esc_html__( 'Use this button to enable %s.', 'outspoken' ), '<strong>' . esc_html__( 'Floating Navigation Menu', 'outspoken' ) . '</strong>' ),
		'std'      => '0',
	),

	array(
		'id'       => 'hide_logo',
		'type'     => 'switch',
		'title'    => esc_html__( 'Show Logo', 'outspoken' ),
		'sub_desc' => wp_kses( __( 'Use this button to Show or Hide the <strong>Logo</strong> completely.', 'outspoken' ), array( 'strong' => '' ) ),
		'std'      => '1',
	),

	array(
		'id'       => 'header_margin',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Margin', 'outspoken' ),
		'sub_desc' => esc_html__( 'Set header margin from here.', 'outspoken' ),
		'left'     => false,
		'right'    => false,
		'std'      => array(
			'top'    => '0',
			'bottom' => '0',
		),
	),
	array(
		'id'       => 'header_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Header Padding', 'outspoken' ),
		'sub_desc' => esc_html__( 'Set header padding from here.', 'outspoken' ),
		'left'     => false,
		'right'    => false,
		'std'      => array(
			'top'    => '28px',
			'bottom' => '28px',
		),
	),

	array(
		'id'       => 'header_border',
		'type'     => 'border',
		'title'    => esc_html__( 'Border', 'outspoken' ),
		'sub_desc' => esc_html__( 'Select border.', 'outspoken' ),
	),

	array(
		'id'    => 'header_nav_heading',
		'type'  => 'heading',
		'title' => esc_html__( 'Header Nav Settings', 'outspoken' ),
	),

	array(
		'id'       => 'header_nav_padding',
		'type'     => 'margin',
		'title'    => esc_html__( 'Nav Padding', 'outspoken' ),
		'sub_desc' => esc_html__( 'Set nav padding from here.', 'outspoken' ),
		'left'     => false,
		'right'    => false,
		'std'      => array(
			'top'    => '14px',
			'bottom' => '13px',
		),
	),

);
